@@ -1,3 +1,3 @@
 from .embedders import CohereEmbedder
-from .project import AtlasProject
+from .project import AtlasProject, AtlasUser
 from .cli import login
\ No newline at end of file
